@@ -687,7 +687,7 @@ makeTSnoise <- function(sampleT,p,lags,noise=NULL, rng=NULL,
   #   the same dimension as noise (or noise generated by noise.model), or a
   #   vector of length equal to the dimension of the noise process (which will
   #   be replicated for all periods.)
- require("setRNG")
+ if(!require("setRNG")) stop("This function requires the setRNG package.")
  if(is.null(rng)) rng <- set.RNG() # returns setting so don't skip if NULL
  else        {old.rng <- set.RNG(rng);  on.exit(set.RNG(old.rng))  }
 
@@ -702,7 +702,8 @@ makeTSnoise <- function(sampleT,p,lags,noise=NULL, rng=NULL,
 
  # Note: noise is added to initial conditions.
  if (!is.null(noise.model))
-   {require("dse1")
+   {if(!require("dse1"))
+       stop("Generating noise with a TSmodel requires the dse1 package.")
     noise <- output.data(simulate(noise.model, sampleT=sampleT+lags))
     noise <- list(w0=noise[1:lags,,drop=FALSE], w=noise[lags+seq(sampleT),,drop=FALSE])
    }
